@@ -1,4 +1,6 @@
 """This API is common to all RLBaselines projects."""
 from rlbcore.api.agents import *  # noqa: F401, F403
+from rlbcore.api.gym_ import *  # noqa: F401, F403
 from rlbcore.api.memory import *  # noqa: F401, F403
+from rlbcore.api.other import *  # noqa: F401, F403
 from rlbcore.api.ui import *  # noqa: F401, F403
