@@ -230,7 +230,9 @@ def _get_path_tree(path: Path) -> dict[str, t.Any]:
     sub_paths = [
         _get_path_tree(p)
         for p in path.iterdir()
-        if not p.name.startswith("_") and not p.name.startswith(".")
+        if not any(
+            (p.name.startswith("_"), p.name.startswith("."), p.name == "py.typed")
+        )
     ]
     if all(x.name != _SECTION_CONFIG_FILE_NAME for x in path.iterdir()):
         return {path.stem: sub_paths}
